@@ -1,6 +1,7 @@
 from keyring import get_password
 from mongoengine import *
 from cryptomodel.operations import OPERATIONS
+from cryptomodel.transaction_types import TRANSACTION_TYPES
 
 
 class user_settings(Document):
@@ -21,8 +22,7 @@ class user_notification(Document):
     check_times = LongField()
     is_active = BooleanField()
     channel_type = StringField()
-    fields_to_send = StringField()  ### collection:field latest date ?
-    ### collection:field by latest user_id ?
+    fields_to_send = StringField()
     source_id = ObjectIdField()
     operation = StringField(choices=OPERATIONS.choices())
 
@@ -30,13 +30,14 @@ class user_notification(Document):
 class user_transaction(Document):
     meta = {'strict': False}
     user_id = IntField()
-    volume = LongField()
+    volume = FloatField()
     symbol = StringField()
-    value = LongField()
-    price = LongField()
+    value = FloatField()
+    price = FloatField()
     date = DateField()
     source = StringField()
     currency = StringField()
+    type = StringField(choices=TRANSACTION_TYPES.choices())
     source_id = ObjectIdField()
     operation = StringField(choices=OPERATIONS.choices())
     is_valid = BooleanField(default=True)
@@ -52,8 +53,6 @@ class user_transaction(Document):
         return self.is_valid
 
 
-
-
 class user_channel(Document):
     meta = {'strict': False}
     user_id = IntField()
